Module sessions_core::data [−][src]
Structs
Represents a JSON key/value type.
Enums
Represents any valid JSON value.
Traits
A data structure that can be deserialized without borrowing any data from the deserializer.
A data structure that can be serialized into any data format supported by Serde.
Functions
Interpret a serde_json::Value as an instance of type T.
Convert a T into serde_json::Value which is an enum that can represent
any valid JSON data.